@@ -18,10 +18,12 @@ extensions = [
     "sphinx.ext.mathjax",
     "sphinx.ext.todo",
     "sphinx_revealjs",
+    "sphinx_revealjs.ext.screenshot",
     "sphinxcontrib.budoux",
     "sphinxcontrib.gtagjs",
     "sphinxcontrib.oembed",
     "sphinxcontrib.sass",
+    "sphinxext.opengraph",
 ]
 templates_path = ["_templates"]
 source_suffix = ".rst"
@@ -115,3 +117,7 @@ sass_targets = {"custom.scss": "custom.css"}
 sass_include_paths = [
     get_theme_path("sphinx_revealjs") / "static" / "revealjs4" / "css" / "theme",
 ]
+
+
+# sphinxext-opengraph
+ogp_site_url = os.environ["DEMO_URL_BASE"]
